<!DOCTYPE xsl:stylesheet [
<!ENTITY % imageEntity SYSTEM "../modules/dtd/image.ent">
%imageEntity;
]>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="html" indent="yes" omit-xml-declaration="yes"/>



<!-- The 'page' parameter is passed from outside and contains the name of the page to generate -->
<xsl:param name="page"/>

<!-- The 'helppage' parameter is passed from outside and contains -->
<!-- the name of the Help Page to generate -->
<xsl:param name="helppage"/>

<xsl:param name="tableborders">1</xsl:param>

<!-- ************* Process only required help page ************* -->

<xsl:template match="/">
	      <xsl:apply-templates select="//HelpPage[@name=$helppage]"/>
</xsl:template>


<!-- Rules for the Help Page -->
<xsl:template match="HelpPage[@name=$helppage]">
	<html>
		<head>
			<link rel="stylesheet" type="text/css" href="/css/help.css" title="naat"/>
			<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"/>
			<title><xsl:value-of select="Title"/>: Help</title>
		</head>

		<body>
			<xsl:apply-templates/>
			<div align="center">
			<a href="javascript:window.close()">
			<img src="../../../&close-en;" border="0" align="center"/>
			</a>
			</div>
		</body>
	</html>
</xsl:template>


<!-- Rules for the title into a page -->
<xsl:template match="HelpPage/Title">
	<xsl:element name="img">
		<xsl:attribute name="src">../../../&help;</xsl:attribute>
		<xsl:attribute name="align">center</xsl:attribute>
		<xsl:attribute name="width">48</xsl:attribute>
		<xsl:attribute name="height">48</xsl:attribute>
		<xsl:attribute name="alt">Help</xsl:attribute>
		<xsl:attribute name="title">Help</xsl:attribute>
	</xsl:element>
	<h1 class="title" align="center">
		<xsl:value-of select="."/>
	</h1>

</xsl:template>


<!-- Rules for a Description tag -->
<xsl:template match="HelpPage/Description">
	<p class="description">
		<xsl:apply-templates/>
	</p>
</xsl:template>

<!-- Rules for a Introduction tag -->
<xsl:template match="HelpPage/Introduction">
	<BLOCKQUOTE>
		<p class="introduction">
			<xsl:value-of select="."/>
		</p>
	</BLOCKQUOTE>
</xsl:template>

<!-- Rules for a Point tag -->
<xsl:template match="HelpPage//Point">
	<ul>
		<li>
			<!--       <xsl:number level="multiple" format="A.1" />  -->
			<xsl:apply-templates/>
		</li>
	</ul>
</xsl:template>

<xsl:template match="HelpPage/Separator">
	<!-- 	<img src="../images/separator.gif" width="100%" height="6" hspace="0" vspace="0" border="0"/> -->
	<HR/>
</xsl:template>



<!-- ************* Container, Inputs and Outputs ************* -->

<!-- Rules for a Container (used to align inputs, for instance) -->
<xsl:template match="HelpPage/Container">
	<table>
		<xsl:attribute name="border">
			<xsl:value-of select="$tableborders"/>
		</xsl:attribute>
		<xsl:apply-templates/>
	</table>
</xsl:template>

<!-- Rule for an Output widget -->
<xsl:template match="HelpPage//Output">
	<tr><td> 
			<b class="output">
				<xsl:value-of select="./Label/."/>
			</b>
		</td>

		<xsl:choose>
			<xsl:when test="./Label/@pos='top'">
				<xsl:text disable-output-escaping="yes">
					<![CDATA[ </tr><tr> ]]></xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<!-- may be used in the future -->
			</xsl:otherwise>
		</xsl:choose>

		<td>
			<xsl:value-of select="Field"/>
		</td>
	</tr>

</xsl:template>

<!-- ************* IMAGE for inline images and icons ************* -->

<xsl:template match="IMAGE">
	<xsl:element name="img">
		<xsl:attribute name="src">
			<xsl:value-of select="@url"/>
		</xsl:attribute>
	</xsl:element>
</xsl:template>

<!-- ************* Screen for literal layout ************* -->

<xsl:preserve-space elements="HelpPage//Screen"/>

<xsl:template match="HelpPage//Screen">
	<xsl:element name="table">
		<xsl:attribute name="border">1</xsl:attribute>
		<xsl:attribute name="bgcolor">#000000</xsl:attribute>
		<TR><TD class="mono">
				<pre><xsl:value-of select="."/></pre>
		</TD></TR>
	</xsl:element>
</xsl:template>



<!-- ************* Ignore all the rest ************* -->

<xsl:template match="/HelpPage[@name=$helppage]">
</xsl:template>

</xsl:stylesheet>

<!-- $Id: help_page.xsl,v 1.6 2002/04/29 17:00:25 philippe Exp $ -->
