<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" indent="yes" omit-xml-declaration="yes"/>

<!-- generate_php_get_dyntable

     This stylesheets generates the right php code to create
     a table, in which each row displays a list for variables.
     Parameters are set in the xsl template for input/dyntable
-->

<xsl:template name="generate_php_get_dyntable">

<xsl:param name="action_name"/>
<xsl:param name="variable_name"/>
<xsl:param name="href_action"/>
<xsl:param name="fields_string"/>
<xsl:param name="param_actions"/>

<xsl:processing-instruction name="php">
	unset ($action_name);
	unset ($variable_name);
	unset ($href_action);
	unset ($fields_string);

	$action_name=&quot;<xsl:value-of select="$action_name"/>&quot;;
	$href_action=&quot;<xsl:value-of select="$href_action"/>&quot;;

	// Simple quotes to prevent php from evaluating variables in the string
	$variable_name='<xsl:value-of select="$variable_name"/>';

	$fields_string=&quot;<xsl:value-of select="$fields_string"/>&quot;;

	$param_actions=&quot;<xsl:value-of select="$param_actions"/>&quot;;

	generate_php_get_dyntable($action_name,$variable_name,$href_action,$fields_string,$param_actions);
?</xsl:processing-instruction>

</xsl:template>


<!-- generate_php_option

     Create an option (a 'row') in Checkbox and Boolean widgets
-->

<xsl:template name="generate_php_option">

<xsl:param name="variable_name"/>
<xsl:param name="type"/>
<xsl:param name="value"/>
<xsl:param name="default"/>
<xsl:param name="label"/>

<xsl:processing-instruction name="php">

unset ($variable_name);
unset ($type);
unset ($value);
unset ($default);
unset ($label);

// Simple quotes to prevent php from evaluating variables in the string
$variable_name='<xsl:value-of select="$variable_name"/>';
$value='<xsl:value-of select="$value"/>';

$type=&quot;<xsl:value-of select="$type"/>&quot;;
$default=&quot;<xsl:value-of select="$default"/>&quot;;
$label=&quot;<xsl:value-of select="$label"/>&quot;;

generate_php_option ($variable_name,$type,$value,$default,$label);

?</xsl:processing-instruction>

</xsl:template>



<!-- generate_php_get_list 

     Generate a dynamic list from an action
     3 types:
     list, boolean, checkbox
-->
	
<xsl:template name="generate_php_get_list">

<xsl:param name="action_name"/>
<xsl:param name="variable_name"/>
<xsl:param name="type"/>
<xsl:param name="param_actions"/>

<xsl:processing-instruction name="php">

unset ($variable_name);
unset ($action_name);
unset ($input_type);
unset ($param_actions);

// Simple quotes to prevent php from evaluating variables in the string
$variable_name='<xsl:value-of select="$variable_name"/>';

$action_name=&quot;<xsl:value-of select="$action_name"/>&quot;;
$input_type=&quot;<xsl:value-of select="$type"/>&quot;;
$param_actions=&quot;<xsl:value-of select="$param_actions"/>&quot;;

generate_php_get_list($variable_name,$input_type,$action_name,$param_actions);

?</xsl:processing-instruction>

</xsl:template>


<!-- generate_php_get_variable

     This stylesheets generates the right php code to get the value of the
     given variable from the backend 
     we use <xsl:processing-instruction> construction to build the 
     php tag 
     sample output	:	
     <?php unset ($AccessType); 
     exec("config-wrapper.pl trans -g  AccessType" , &$AccessType, &$var);
     print $AccessType[0];
     ?>
-->

<xsl:template name="generate_php_get_variable">

<xsl:param name="variable_name"/>
<xsl:param name="action_name"/>
<xsl:param name="type"/>
<xsl:param name="type_field"/>

<xsl:processing-instruction name="php">

unset ($variable_name);
unset ($action_name);
unset ($input_type);
unset ($field_type);

// Simple quotes to prevent php from evaluating variables in the string
$variable_name='<xsl:value-of select="$variable_name"/>';

$action_name=&quot;<xsl:value-of select="$action_name"/>&quot;;
$input_type=&quot;<xsl:value-of select="$type"/>&quot;;
$type_field=&quot;<xsl:value-of select="$type_field"/>&quot;;
generate_php_get_variable($variable_name,$input_type,$action_name,$type_field);

?</xsl:processing-instruction>

</xsl:template>



<!-- spaces

     Simple tempate to create four nbspaces. 
     Please, add a parameter ! 
-->
<xsl:template name="spaces">
	<xsl:text
	disable-output-escaping="yes">&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;</xsl:text>
</xsl:template>


<!-- Other small templates
-->
<xsl:template name="Label">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template name="Navigation"/>

</xsl:stylesheet>

<!-- $Id: php_func_rino.xsl,v 1.1.1.1 2001/06/13 11:38:15 rchaillat Exp $ -->

