/*
 Copyright (C) 2002 MandrakeSoft SA
 
 This program may be distributed and/or
 modified under the terms of the GNU General Public
 License version 2 as published by the Free Software Foundation
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 General Public License for more details.
 
 Licensees holding valid MandrakeSecurity MNF Commercial License may use this
 file in  accordance with the MandrakeSecurity MNF Commercial License Agreement
 provided with the Software.
 
 See http://www.mandrakesoft.com/mnf/license for information about MandrakeSecurity MNF Commercial License Agrrement.
*/ 
#ifndef _BACKEND_H_
#define _BACKEND_H_

#include <stdio.h>

typedef struct _wvm_instruction
{
  int pc;
  int useless;

  void (* printer)(struct _wvm_instruction *self, FILE *out);

  struct _wvm_instruction *next;

  struct _wvm_instruction *last; /* append optimization */
} wvm_instruction_t;


typedef struct _wvm_push_instruction
{
  wvm_instruction_t instr;
} wvm_push_instruction_t;


typedef struct _wvm_pop_instruction
{
  wvm_instruction_t instr;
} wvm_pop_instruction_t;


typedef struct _wvm_halt_instruction
{
  wvm_instruction_t instr;
} wvm_halt_instruction_t;


typedef struct _wvm_exec_instruction
{
  wvm_instruction_t instr;

  const char *script;
} wvm_exec_instruction_t;


typedef struct _wvm_if_instruction
{
  wvm_instruction_t instr;

  const char *status;
  wvm_instruction_t *then_target;
  wvm_instruction_t *else_target;
} wvm_if_instruction_t;


typedef struct _wvm_goto_instruction
{
  wvm_instruction_t instr;

  wvm_instruction_t *target;
} wvm_goto_instruction_t;


typedef struct _wvm_show_instruction
{
  wvm_instruction_t instr;

  const char *page;
} wvm_show_instruction_t;


extern wvm_instruction_t *wvm_make_push(void);
extern wvm_instruction_t *wvm_make_pop(void);
extern wvm_instruction_t *wvm_make_halt(void);
extern wvm_instruction_t *wvm_make_exec(const char *script);
extern wvm_instruction_t *wvm_make_if(const char *status, wvm_instruction_t *then_target, wvm_instruction_t *else_target);
extern wvm_instruction_t *wvm_make_goto(wvm_instruction_t *target);
extern wvm_instruction_t *wvm_make_show(const char *page);

extern void wvm_set_page_prefix(const  char *page_prefix);
extern void wvm_print_code(wvm_instruction_t *instr, FILE *out);
extern void wvm_append(wvm_instruction_t *instr, wvm_instruction_t *append);

#endif
