/*
 Copyright (C) 2002 MandrakeSoft SA
 
 This program may be distributed and/or
 modified under the terms of the GNU General Public
 License version 2 as published by the Free Software Foundation
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 General Public License for more details.
 
 Licensees holding valid MandrakeSecurity MNF Commercial License may use this
 file in  accordance with the MandrakeSecurity MNF Commercial License Agreement
 provided with the Software.
 
 See http://www.mandrakesoft.com/mnf/license for information about MandrakeSecurity MNF Commercial License Agrrement.
*/ 
#include <stdio.h>
#include <stdlib.h>

#include "syntax.h"
#include "parser.h"
#include "generator.h"

/**
 * Compiler for the Wat xml files. Uses SAX (file parser.c)  to parse the input and a proprietary tree 
 * (file syntax.h) as syntactic tree. 
 * The compilation is a three-step process:
 * 1) Mark all the syntactic  nodes with a "line number"
 * 2) Static analysis: determines the next node of every syntactic nodes
 * 3) Code generation.
 *
 */


/* Parses the wat file, perform a static flow analysis, and generates the code. */

void wat_compile(const  char *filename)
{
  wat_node_t *tree;

  tree = wat_parse(filename);

  if (tree == 0)
    {
      fprintf(stderr, "Syntax error in file %s\n", filename);
      exit(0);			/* need better error handling !!! */
    }
    
  wat_generate_code(tree, stdout);
}

static int wat_compiler_debug = 0;

void wat_set_debug(int debug)
{
  wat_compiler_debug = debug;
}

int wat_get_debug(void)
{
  return wat_compiler_debug;
}

