/*
 Copyright (C) 2002 MandrakeSoft SA
 
 This program may be distributed and/or
 modified under the terms of the GNU General Public
 License version 2 as published by the Free Software Foundation
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 General Public License for more details.
 
 Licensees holding valid MandrakeSecurity MNF Commercial License may use this
 file in  accordance with the MandrakeSecurity MNF Commercial License Agreement
 provided with the Software.
 
 See http://www.mandrakesoft.com/mnf/license for information about MandrakeSecurity MNF Commercial License Agrrement.
*/ 
#include <string.h>
#include <stdlib.h>

#include "syntax.h"


/* Utilities */


#define wat_node_init(node, type) wat_node_init_node((wat_node_t *)(node), type)

void wat_node_init_node(wat_node_t *node, wat_node_type_t type)
{
  node->type = type;
  node->next   = 0;
  node->childs = 0;
  node->parent = 0;
}

/* Constructors */

wat_node_t *wat_node_new_root()
{
  wat_root_node_t *node;

  node = (wat_root_node_t *) malloc(sizeof(wat_root_node_t));
  wat_node_init(node, wat_root_node_type);

  return (wat_node_t *) node;
}


wat_node_t *wat_node_new_wizard()
{
  wat_wizard_node_t *node;

  node = (wat_wizard_node_t *) malloc(sizeof(wat_wizard_node_t));
  wat_node_init(node, wat_wizard_node_type);

  return (wat_node_t *) node;
}


wat_node_t *wat_node_new_if(const char *test, const char *status)
{
  wat_if_node_t *node;

  node = (wat_if_node_t *) malloc(sizeof(wat_if_node_t));
  wat_node_init(node, wat_if_node_type);
  node->test   = strdup(test);
  node->status = strdup(status);

  return (wat_node_t *) node;
}


wat_node_t *wat_node_new_then()
{
  wat_then_node_t *node;

  node = (wat_then_node_t *) malloc(sizeof(wat_then_node_t));
  wat_node_init(node, wat_then_node_type);

  return (wat_node_t *) node;
}


wat_node_t *wat_node_new_else()
{
  wat_else_node_t *node;

  node = (wat_else_node_t *) malloc(sizeof(wat_else_node_t));
  wat_node_init(node, wat_else_node_type);

  return (wat_node_t *) node;
}


wat_node_t *wat_node_new_switch(const char *test)
{
  wat_switch_node_t *node;

  node = (wat_switch_node_t *) malloc(sizeof(wat_switch_node_t));
  wat_node_init(node, wat_switch_node_type);
  node->test   = strdup(test);

  return (wat_node_t *) node;
}


wat_node_t *wat_node_new_case(const char *status)
{
  wat_case_node_t *node;

  node = (wat_case_node_t *) malloc(sizeof(wat_case_node_t));
  wat_node_init(node, wat_case_node_type);
  node->status = strdup(status);

  return (wat_node_t *) node;
}


wat_node_t *wat_node_new_default()
{
  wat_default_node_t *node;

  node = (wat_default_node_t *) malloc(sizeof(wat_default_node_t));
  wat_node_init(node, wat_default_node_type);

  return (wat_node_t *) node;
}


wat_node_t *wat_node_new_while(const char *test, const char *status)
{
  wat_while_node_t *node;

  node = (wat_while_node_t *) malloc(sizeof(wat_while_node_t));
  wat_node_init(node, wat_while_node_type);
  node->test   = strdup(test);
  node->status = strdup(status);

  return (wat_node_t *) node;
}


wat_node_t *wat_node_new_page(const char *name)
{
  wat_page_node_t *node;

  node = (wat_page_node_t *) malloc(sizeof(wat_page_node_t));
  wat_node_init(node, wat_page_node_type);
  node->name  = strdup(name);

  return (wat_node_t *) node;
}

wat_node_t *wat_node_new_call(const char *script)
{
  wat_call_node_t *node;

  node = (wat_call_node_t *) malloc(sizeof(wat_call_node_t));
  wat_node_init(node, wat_call_node_type);
  node->script  = strdup(script);

  return (wat_node_t *) node;
}


void wat_node_delete(wat_node_t *node)
{
  if (wat_node_is_if(node))
    {
      free((void *) ((wat_if_node_t *)node)->test);
      free((void *) ((wat_if_node_t *)node)->status);
    }
  else if (wat_node_is_while(node))
    {
      free((void *) ((wat_while_node_t *)node)->test);
      free((void *) ((wat_while_node_t *)node)->status);
    }
  else if (wat_node_is_switch(node))
    {
      free((void *) ((wat_if_node_t *)node)->test);
    }
  else if (wat_node_is_case(node))
    {
      free((void *) ((wat_if_node_t *)node)->status);
    }
  else if (wat_node_is_page(node))
    {
      free((void *) ((wat_page_node_t *)node)->name);
    }
  else if (wat_node_is_call(node))
    {
      free((void *) ((wat_call_node_t *)node)->script);
    }

  /* Safe clean  up */

  wat_node_init(node, wat_void_node_type);
  free(node);
}


/* Node Navigation macros and functions */

wat_node_t *wat_node_get_sibling_of_type(wat_node_t *node, wat_node_type_t type)
{
  wat_node_t *p;

  for (p = node; p; p = wat_node_get_sibling(p))
    if (wat_node_get_type(p) == type)
      return p;

  return 0;
}


wat_node_t *wat_node_get_first_child_of_type(wat_node_t *node, wat_node_type_t type)
{
  wat_node_t *p;

  for (p = wat_node_get_first_child(node); p; p = wat_node_get_sibling(p))
    if (wat_node_get_type(p) == type)
      return p;

  return 0;
}


/* tree construction */

void wat_node_add_child(wat_node_t *node, wat_node_t *child)
{
  wat_node_t *p;

  p = wat_node_get_first_child(node);

  if (! p)
    node->childs = child;
  else
    {
      while (wat_node_get_sibling(p))
	p = wat_node_get_sibling(p);

      p->next = child;
    }

  child->parent = node;
}
