/*
 Copyright (C) 2002 MandrakeSoft SA
 
 This program may be distributed and/or
 modified under the terms of the GNU General Public
 License version 2 as published by the Free Software Foundation
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 General Public License for more details.
 
 Licensees holding valid MandrakeSecurity MNF Commercial License may use this
 file in  accordance with the MandrakeSecurity MNF Commercial License Agreement
 provided with the Software.
 
 See http://www.mandrakesoft.com/mnf/license for information about MandrakeSecurity MNF Commercial License Agrrement.
*/ 
#ifndef _SYNTAX_H_
#define _SYNTAX_H_

#include  "backend.h"

/* Define the structures representing the tree in memory */

#define WAT_TAG    "Wat"
#define WIZARD_TAG "Wizard"
#define PAGE_TAG   "Page"
#define IF_TAG     "If"
#define THEN_TAG   "Then"
#define ELSE_TAG   "Else"
#define WHILE_TAG  "While"
#define SWITCH_TAG "Switch"
#define CASE_TAG   "Case"
#define DEFAULT_TAG   "Default"
#define CALL_TAG   "Call"

struct _wat_node;

typedef struct _wat_node_type_descr
{
  wvm_instruction_t  *(* generate)(struct _wat_node *node);
} wat_node_type_descr_t;

typedef wat_node_type_descr_t *wat_node_type_t;


extern wat_node_type_t wat_void_node_type;
extern wat_node_type_t wat_root_node_type;
extern wat_node_type_t wat_wizard_node_type;
extern wat_node_type_t wat_if_node_type;
extern wat_node_type_t wat_then_node_type;
extern wat_node_type_t wat_else_node_type;
extern wat_node_type_t wat_switch_node_type;
extern wat_node_type_t wat_case_node_type;
extern wat_node_type_t wat_default_node_type;
extern wat_node_type_t wat_while_node_type;
extern wat_node_type_t wat_page_node_type;
extern wat_node_type_t wat_call_node_type;



typedef struct _wat_node
{
  wat_node_type_t    type;
  struct _wat_node  *next;
  struct _wat_node  *childs;
  struct _wat_node  *parent;
} wat_node_t;


typedef struct _wat_root_node
{
  wat_node_t node;
} wat_root_node_t;


typedef struct _wat_wizard_node
{
  wat_node_t node;
} wat_wizard_node_t;


typedef struct _wat_if_node
{
  wat_node_t   node;
  const char  *test;
  const char  *status;
} wat_if_node_t;


typedef struct _wat_then_node
{
  wat_node_t node;
} wat_then_node_t;


typedef struct _wat_else_node
{
  wat_node_t node;
} wat_else_node_t;

typedef struct _wat_switch_node
{
  wat_node_t   node;
  const char  *test;
} wat_switch_node_t;


typedef struct _wat_case_node
{
  wat_node_t   node;
  const char  *status;
} wat_case_node_t;


typedef struct _wat_default_node
{
  wat_node_t   node;
} wat_default_node_t;


typedef struct _wat_while_node
{
  wat_node_t   node;
  const char  *test;
  const char  *status;
} wat_while_node_t;


typedef struct _wat_page_node
{
  wat_node_t node;
  const char   *name;
} wat_page_node_t;


typedef struct _wat_call_node
{
  wat_node_t node;
  const char   *script;
} wat_call_node_t;



/* Type check macros  */

#define wat_node_is_root(node)           (((wat_node_t *)(node))->type == wat_root_node_type)
#define wat_node_is_wizard(node)         (((wat_node_t *)(node))->type == wat_wizard_node_type)
#define wat_node_is_page(node)           (((wat_node_t *)(node))->type == wat_page_node_type)
#define wat_node_is_while(node)          (((wat_node_t *)(node))->type == wat_while_node_type)
#define wat_node_is_if(node)             (((wat_node_t *)(node))->type == wat_if_node_type)
#define wat_node_is_then(node)           (((wat_node_t *)(node))->type == wat_then_node_type)
#define wat_node_is_else(node)           (((wat_node_t *)(node))->type == wat_else_node_type)
#define wat_node_is_switch(node)         (((wat_node_t *)(node))->type == wat_switch_node_type)
#define wat_node_is_case(node)           (((wat_node_t *)(node))->type == wat_case_node_type)
#define wat_node_is_default(node)        (((wat_node_t *)(node))->type == wat_default_node_type)
#define wat_node_is_call(node)           (((wat_node_t *)(node))->type == wat_call_node_type)

/* Syntax/Semantic type check macros */

#define wat_node_is_a_loop(node)       (wat_node_is_while((node)))

/* Code generation related macros */

#define wat_node_generate_code(node)  ((* ((node)->type->generate))((node)))

/* Constructors */

extern wat_node_t *wat_node_new_root(void);
extern wat_node_t *wat_node_new_wizard(void);
extern wat_node_t *wat_node_new_if(const char *test, const char *status);
extern wat_node_t *wat_node_new_then(void);
extern wat_node_t *wat_node_new_else(void);
extern wat_node_t *wat_node_new_while(const char *test, const char *status);
extern wat_node_t *wat_node_new_page(const char *name);
extern wat_node_t *wat_node_new_switch(const char *test);
extern wat_node_t *wat_node_new_case(const char *status);
extern wat_node_t *wat_node_new_default(void);
extern wat_node_t *wat_node_new_call(const char *script);


/* Destructor */

extern void wat_node_delete(wat_node_t *node);

/* Node Navigation macros and functions */

#define wat_node_get_type(node)          (((wat_node_t *)(node))->type)
#define wat_node_get_parent(node)        (((wat_node_t *)(node))->parent)
#define wat_node_get_first_child(node)   (((wat_node_t *)(node))->childs)

extern wat_node_t *wat_node_get_sibling_of_type(wat_node_t *node, wat_node_type_t type);
extern wat_node_t *wat_node_get_first_child_of_type(wat_node_t *node, wat_node_type_t type);

#define wat_node_get_sibling(node)       (((wat_node_t *)(node))->next)
#define wat_node_is_empty(node)          (! ((wat_node_t *)(node))->childs)

/* Tree construction */

#define wat_node_set_parent(node, p)     (((wat_node_t *)(node))->parent = (p))

extern void wat_node_add_child(wat_node_t *node, wat_node_t *child);

/* Selectors */

#define wat_if_node_get_test(node)       (((wat_if_node_t *)(node))->test)
#define wat_if_node_get_status(node)     (((wat_if_node_t *)(node))->status)
#define wat_while_node_get_test(node)    (((wat_while_node_t *)(node))->test)
#define wat_while_node_get_status(node)  (((wat_while_node_t *)(node))->status)
#define wat_page_node_get_name(node)     (((wat_page_node_t *)(node))->name)
#define wat_switch_node_get_test(node)   (((wat_switch_node_t *)(node))->test)
#define wat_case_node_get_status(node)   (((wat_case_node_t *)(node))->status)
#define wat_call_node_get_script(node)   (((wat_call_node_t *)(node))->script)


#endif
