
package com.mandrakesoft.wat;

import org.w3c.dom.*;
import java.io.*;
import org.apache.xerces.dom.NodeImpl;

/**
 * A test front-end for the wat compiler. It just prints out the syntactic nodes, in the
 * format "tag [lineNumber:nextNode] "*/

public class TestGenerator implements Generator {

  public TestGenerator()
  {
  }

  /**
   * Prints the nodes. */

  public void generateCode(Document doc)
  {
    generateCode(doc.getDocumentElement(), System.out);
  }

  /**
   * Actually print out the tree */

  private void generateCode(Node node, PrintStream out)
  {

    if (Syntax.isSyntacticNode(node))
      {
	if (Syntax.isExecutable(node))
	  generateNodeCode(node, out);
      
	for (int i=0; i < node.getChildNodes().getLength(); i++)
	  generateCode(node.getChildNodes().item(i), out);
      }
  }
  

  private void generateNodeCode(Node node, PrintStream out)
  {
    CompilerInfo info = Syntax.getCompilerInfo(node);

    if (Syntax.isIf(node))
      {
	CompilerInfo thenInfo = Syntax.getCompilerInfo(Syntax.getFirstChild(Syntax.getFirstChild(node, Syntax.thenTag)));
	CompilerInfo elseInfo = Syntax.getCompilerInfo(Syntax.getFirstChild(Syntax.getFirstChild(node, Syntax.elseTag)));

	out.println(info.getLineNo() + "\tIF\t" + Syntax.getAttribute(node, "test")  + "\t" +
		    Syntax.getAttribute(node, "status") + "\t" + + thenInfo.getLineNo() + "\t" + elseInfo.getLineNo());
      }
    else if (Syntax.isWhile(node))
      {
	CompilerInfo childInfo = Syntax.getCompilerInfo(Syntax.getFirstChild(node));

	out.println(info.getLineNo() + "\tIF\t" + Syntax.getAttribute(node, "test")  + "\t" +
		    Syntax.getAttribute(node, "status") + "\t" + childInfo.getLineNo() + "\t" + info.getNext());
      }     
    else if (Syntax.isPage(node))
      {
	out.println(info.getLineNo() + "\tSHOW\t" + Syntax.getAttribute(node, "name") + "\t" + info.getNext());
      }     
  }
}
