<?xml version="1.0"?>

<!DOCTYPE stylesheet [
<!ENTITY imgwidth  "<![CDATA[&img-width;]]>" >
]>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="xml" omit-xml-declaration="yes" indent="yes"/>


<!-- Rules for the Help Page -->
  <xsl:template match="HelpPage">
	      <xsl:apply-templates/>
  </xsl:template>

<!-- Rules for the title -->
<xsl:template match="Title">
  <title>
    <xsl:value-of select="."/>
  </title>
  
  <mediaobject>
    <!--    <imageobject>
      <imagedata revision="1" format="EPS">
        <xsl:attribute name="fileref">images/naat-screen-<xsl:value-of select="../@name"/>.pdf</xsl:attribute>
        <xsl:attribute name="width">15cm</xsl:attribute>
      </imagedata>
    </imageobject>
 -->
    <imageobject>
      <imagedata revision="1" format="PNG" align="center">
        <xsl:attribute name="width">15cm</xsl:attribute>
        <xsl:attribute name="fileref">images/naat-screen-<xsl:value-of select="../@name"/>.png</xsl:attribute>
      </imagedata>
    </imageobject>
  </mediaobject>
  
</xsl:template>

<!-- Rules for a Introduction tag -->
<xsl:template match="Introduction">
<abstract>
<para>
    <xsl:value-of select="."/>
</para>
</abstract>
</xsl:template>


<!-- Rules for a Description tag -->
<xsl:template match="Description">
      <xsl:call-template name="para"/>
</xsl:template>

<xsl:template name="para">
  <xsl:choose>
    <xsl:when test='@role'>
      <xsl:call-template name="admonition"/>
    </xsl:when>
    <xsl:otherwise>
      <para>
        <xsl:apply-templates/>
      </para>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<!-- Rules for a Point tag -->
<xsl:template match="points">
<itemizedlist>
      <xsl:apply-templates/>
</itemizedlist>
</xsl:template>
	
<xsl:template match="Point">
  <listitem>
    <xsl:call-template name="para"/>
  </listitem>
</xsl:template>

<!-- Admonitions paras -->

<xsl:template name="admonition">
  <xsl:element name="{@role}">
    <para>
      <xsl:apply-templates/>
    </para>
  </xsl:element>
</xsl:template>
	
<!-- Rules for a Separator tag -->
<xsl:template match="Separator"/>



<!-- ************* Container, Inputs and Outputs ************* -->

<!-- Rules for a Container (used to align inputs, for instance) -->
<xsl:template match="Container">
  <informaltable>
    <tgroup>
	<xsl:attribute name="cols">2</xsl:attribute>   
	<xsl:attribute name="align">left</xsl:attribute>   
	<xsl:attribute name="colsep">1</xsl:attribute>   
	<xsl:attribute name="rowsep">1</xsl:attribute>
        <colspec colwidth='1*'/>
        <colspec colwidth='2*'/>
    <tbody>
	<xsl:apply-templates/>
    </tbody>
    </tgroup>
  </informaltable>
</xsl:template>

<!-- Rule for an Output widget -->
<xsl:template match="Output">
 <row><entry> 
	<emphasis>
		<xsl:value-of select="./Label/."/>
	</emphasis>
    </entry>

  <entry><xsl:value-of select="Field"/></entry>
 </row>

</xsl:template>


<xsl:template match="IMAGE">
  <xsl:variable name="imgentity" select="@url"/>
  <inlinegraphic width="0.9cm">
    <xsl:attribute name="fileref"><xsl:value-of select="substring-before(translate(substring-after($imgentity,'../../../'),'_','-'),'.png')"/>.png</xsl:attribute>
  </inlinegraphic>
  <!--
  <inlinemediaobject>
    <imageobject>
      <imagedata revision="1" format="EPS">
         <xsl:attribute name="fileref"><xsl:value-of select="translate(substring-after($imgentity,'../../../'),'_','-')"/></xsl:attribute>
      </imagedata>
    </imageobject>
    <imageobject>
      <imagedata revision="1" format="PNG">
         <xsl:attribute name="fileref"><xsl:value-of select="translate(substring-after($imgentity,'../../../'),'_','-')"/></xsl:attribute>
      </imagedata>
    </imageobject>
  </inlinemediaobject>
-->
</xsl:template>

<!-- ************* Screen for literal layout ************* -->

<xsl:preserve-space elements="Screen"/>
<xsl:template match="Screen">
<screen><xsl:value-of select="."/></screen>
</xsl:template>


</xsl:stylesheet>